summaryrefslogtreecommitdiffstats
path: root/conf
diff options
context:
space:
mode:
authorOndrej Zajicek <santiago@crfreenet.org>2010-01-03 12:17:52 +0100
committerOndrej Zajicek <santiago@crfreenet.org>2010-01-03 12:17:52 +0100
commitcf31112f0d7618464097f71228f84bd534f1bc0f (patch)
tree68f7fa93bd2154a16169b4db3dc9c16e51c2e84f /conf
parent610bb3cff05f6d5b09c77724bc97295b809d15e2 (diff)
downloadbird-cf31112f0d7618464097f71228f84bd534f1bc0f.tar
bird-cf31112f0d7618464097f71228f84bd534f1bc0f.zip
Implements MRTdump feature.
Diffstat (limited to 'conf')
-rw-r--r--conf/conf.c1
-rw-r--r--conf/conf.h5
2 files changed, 5 insertions, 1 deletions
diff --git a/conf/conf.c b/conf/conf.c
index eeffd4a..7ffe8d1 100644
--- a/conf/conf.c
+++ b/conf/conf.c
@@ -75,6 +75,7 @@ config_alloc(byte *name)
linpool *l = lp_new(p, 4080);
struct config *c = lp_allocz(l, sizeof(struct config));
+ c->mrtdump_file = -1; /* Hack, this should be sysdep-specific */
c->pool = p;
cfg_mem = c->mem = l;
c->file_name = cfg_strdup(name);
diff --git a/conf/conf.h b/conf/conf.h
index 951dde3..f8ab713 100644
--- a/conf/conf.h
+++ b/conf/conf.h
@@ -20,12 +20,15 @@ struct config {
list protos; /* Configured protocol instances (struct proto_config) */
list tables; /* Configured routing tables (struct rtable_config) */
list logfiles; /* Configured log fils (sysdep) */
+ int mrtdump_file; /* Configured MRTDump file (sysdep, fd in unix) */
struct rtable_config *master_rtc; /* Configuration of master routing table */
+
u32 router_id; /* Our Router ID */
ip_addr listen_bgp_addr; /* Listening BGP socket should use this address */
unsigned listen_bgp_port; /* Listening BGP socket should use this port (0 is default) */
u32 listen_bgp_flags; /* Listening BGP socket should use these flags */
- unsigned int proto_default_debug; /* Default protocol debug mask */
+ unsigned proto_default_debug; /* Default protocol debug mask */
+ unsigned proto_default_mrtdump; /* Default protocol mrtdump mask */
int cli_debug; /* Tracing of CLI connections and commands */
char *err_msg; /* Parser error message */
int err_lino; /* Line containing error */